Learn R Programming

demoGraphic (version 0.1.0)

my.fisher: fisher exact test to get p value if any cell in propotion table of expect value less than 5

Description

fisher exact test to get p value if any cell in propotion table of expect value less than 5

Usage

my.fisher(...)

Arguments

...

variables

Examples

Run this code
# NOT RUN {
set.seed(2018)
data_check <-data.frame(
  group <-round(abs(rnorm(500)*10),0) %% 2,
  cat_multi_1 <-round(abs(rnorm(500)*10),0) %% 3)
my.fisher(table(data_check$cat_multi_1, data_check$group))
# }

Run the code above in your browser using DataLab