Learn R Programming

demoGraphic (version 0.1.0)

mydocx: write smd table or demographic table into docx file

Description

write smd table or demographic table into docx file

Usage

mydocx(smd_table, name)

Arguments

smd_table

smd table or demo graphic table.

name

file name to save

Examples

Run this code
# NOT RUN {
mydocx(data.frame(smd.value <- 3.4, smd.lo <- 1.1, smd.up <- 5.6),"smd_table")
# }

Run the code above in your browser using DataLab