Learn R Programming

demoGraphic (version 0.1.0)

smd_ci: Confident interval for smd

Description

Confident interval for smd

Usage

smd_ci(n1, n2, smd)

Arguments

n1

length of a baseline variable in the treatment group.

n2

length of a baseline variable in the control group.

smd

smd value

Value

vector of 95

Examples

Run this code
# NOT RUN {
smd_ci(10,12,0.3)
# }

Run the code above in your browser using DataLab