powered by
Confident interval for smd
smd_ci(n1, n2, smd)
length of a baseline variable in the treatment group.
length of a baseline variable in the control group.
smd value
vector of 95
# NOT RUN { smd_ci(10,12,0.3) # }
Run the code above in your browser using DataLab